#----------------------------------->
#Example of cursor control over a scene element.
#Julian Oliver 2005
#Known to work with Blender 2.42a but only when using the 'Sumo' physics engine.
#Press 'p' in the viewport and move the mouse around (careful, control is sensitive)
#Press the ESC key to quit
#< ---------------------------------

#import game engine classes
import GameLogic

#import game window classes
import Rasterizer

#allow the desktop environment's cursor to be seen on the screen
Rasterizer.showMouse(1)

#get the current controller for the object (this script)
c = GameLogic.getCurrentController()

#find the object that owns this controller
cursor = c.getOwner()

#get the actuator 'move' for use in this script
move = c.getActuator("move")

#make a motion scale multiplier (x, y)
motion = (-.002, .002)

#set up our movement sensor and call it 'mouseMove'
mouseMove = c.getSensor("sensor")

#setup our near sensor and call it 'mouseNear'
mouseNear = c.getSensor("sensor1")

#find the objects we 'hit' at runtime
hit = mouseNear.getHitObject()

print "Window Width", Rasterizer.getWindowWidth()

#make a function that works out the mouse position

def mousePos():
	
	# calculate mouse position within the drawspace
	# and multiply it with 'motion' to fit world scale.
	
	x = (Rasterizer.getWindowWidth()/2 - mouseMove.getXPosition())*motion[0]
	y = (Rasterizer.getWindowHeight()/2 - mouseMove.getYPosition())*motion[1]
	
	#print output for reference
	
	print x, y
		
	print "mouse x, y pos", mouseMove.getXPosition(), mouseMove.getYPosition()
	
	#value returned by function for use outside of the function.
	return (x, y)

pos=mousePos()

#place virtual cursor using delta location
move.setDLoc(pos[0],pos[1],0.0,1)

#activate the actuator 'move' (boolean)
GameLogic.addActiveActuator(move, 1) 

#a loop to detect collisions with an object and print the name of the mesh
#you can use this event to trigger anything.

if hit:
	print "Collided with: ", hit.getMesh(), "with property named: ", mouseNear.getProperty()

# so we can see where we're upto frame by frame in the output
print "<----------------end frame---------------->"
	